import {Injectable} from '@angular/core';
import {HttpClient, HttpHeaders} from '@angular/common/http';
import {Observable} from 'rxjs';
import {Author} from '../models/author';

@Injectable({
  providedIn: 'root'
})
export class AuthorService {

  constructor(private httpClient: HttpClient) {}

  list(): Observable<Author[]> {
    return this.httpClient.get<Author[]>("http://localhost:8080/api/authors");
  }

  login(name: string, password: string) {
    return this.httpClient.post<any>("http://localhost:8080/api/authors/login", {name: name, password: password})
  }

  me(token: string): Observable<Author> {
    const headers = new HttpHeaders().set("Authorization", "Bearer " + token);
    return this.httpClient.get<Author>("http://localhost:8080/api/authors/me", {'headers': headers});
  }

  attributePost(authorId: string | undefined, postId: bigint, token: string) {
    const httpOptions = {
      headers: new HttpHeaders({
        'Authorization': `Bearer ${token}`
      })
    };
    return this.httpClient.put<any>(`http://localhost:8080/api/authors/${authorId}/posts`, postId, httpOptions);
  }

  getAuthor(id: string | null): Observable<Author> {
    if (id) {
      return this.httpClient.get<Author>("http://localhost:8080/api/authors/" + id);
    } else {
      throw new Error("Not Found");
    }
  }
}
